package com.ruoyi.busi.service;

import java.util.List;
import com.ruoyi.busi.domain.JzObject;

/**
 * 社区矫正对象基础信息(标准7)Service接口
 * 
 * @author ruoyi
 * @date 2026-07-23
 */
public interface IJzObjectService 
{
    /**
     * 查询社区矫正对象基础信息(标准7)
     * 
     * @param SQJZDXBH 社区矫正对象基础信息(标准7)主键
     * @return 社区矫正对象基础信息(标准7)
     */
    public JzObject selectJzObjectBySQJZDXBH(String SQJZDXBH);

    /**
     * 查询社区矫正对象基础信息(标准7)列表
     * 
     * @param jzObject 社区矫正对象基础信息(标准7)
     * @return 社区矫正对象基础信息(标准7)集合
     */
    public List<JzObject> selectJzObjectList(JzObject jzObject);

    /**
     * 新增社区矫正对象基础信息(标准7)
     * 
     * @param jzObject 社区矫正对象基础信息(标准7)
     * @return 结果
     */
    public int insertJzObject(JzObject jzObject);

    /**
     * 修改社区矫正对象基础信息(标准7)
     * 
     * @param jzObject 社区矫正对象基础信息(标准7)
     * @return 结果
     */
    public int updateJzObject(JzObject jzObject);

    /**
     * 批量删除社区矫正对象基础信息(标准7)
     * 
     * @param SQJZDXBHs 需要删除的社区矫正对象基础信息(标准7)主键集合
     * @return 结果
     */
    public int deleteJzObjectBySQJZDXBHs(String[] SQJZDXBHs);

    /**
     * 删除社区矫正对象基础信息(标准7)信息
     * 
     * @param SQJZDXBH 社区矫正对象基础信息(标准7)主键
     * @return 结果
     */
    public int deleteJzObjectBySQJZDXBH(String SQJZDXBH);
}
